/* This file is part of the KDE libraries
    Copyright (C) 2005, 2006 KJSEmbed Authors
    See included AUTHORS file.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef QSVG_BINDING_H
#define QSVG_BINDING_H

#include <QtSvg/QSvgRenderer>
#include <QtSvg/QSvgWidget>
#include "qwidget_binding.h"
#include "qobject_binding.h"

namespace KJSEmbed
{
    KJSO_BINDING( SvgRenderer, QSvgRenderer, QObjectBinding )
    KJSO_BINDING( SvgWidget, QSvgWidget, QWidgetBinding )
}
#endif

//kate: indent-spaces on; indent-width 4; replace-tabs on; indent-mode cstyle;
